@@ -33,7 +33,6 @@ if tp.TYPE_CHECKING:
 
 __all__ = (
     "get_current_frame_content_entire_size",
-    "get_device_pixel_ratio",
     "get_viewport_size",
     "get_window_size",
     "set_window_size",
@@ -186,11 +185,6 @@ def get_current_frame_content_entire_size(driver):
     return RectangleSize(width, height)
 
 
-def get_device_pixel_ratio(driver):
-    # type: (AnyWebDriver) -> float
-    return driver.execute_script("return window.devicePixelRatio;")
-
-
 def get_viewport_size(driver):
     # type: (AnyWebDriver) -> RectangleSize
     """
@@ -286,17 +280,14 @@ def set_viewport_size(driver, required_size):  # noqa
     # non-maximized, so the original browser size calculation is
     # wrong).
     logger.info("Trying workaround for maximization...")
-    if set_browser_size_by_viewport_size(driver, actual_viewport_size, required_size):
-        return None
-
+    actual_viewport_size = get_viewport_size(driver)
     width_diff = abs(actual_viewport_size["width"] - required_size["width"])
     width_step = -1 if width_diff > 0 else 1  # -1 for smaller size, 1 for larger
     height_diff = abs(actual_viewport_size["height"] - required_size["height"])
     height_step = -1 if height_diff > 0 else 1
 
     browser_size = get_window_size(driver)
-    curr_width_change = 0
-    curr_height_change = 0
+    curr_width_change = curr_height_change = 0
 
     if width_diff <= _MAX_DIFF and height_diff <= _MAX_DIFF:
         logger.info("Trying workaround for zoom...")
