@@ -15,15 +15,17 @@ from applitools.common.geometry import Point
 from applitools.common.utils import argument_guard, cached_property, image_utils
 from applitools.common.utils.compat import basestring
 from applitools.common.utils.general_utils import all_attrs, proxy_to
+from applitools.selenium import webdriver_sync
 from applitools.selenium.fluent import FrameLocator
 
 from . import eyes_selenium_utils, useragent
 from .frames import Frame, FrameChain
 from .positioning import ScrollPositionProvider
+from .useragent import UserAgent
 from .webelement import EyesWebElement
 
 if typing.TYPE_CHECKING:
-    from typing import Any, Dict, Generator, List, Optional, Text, Union
+    from typing import Any, ContextManager, Dict, Generator, List, Optional, Text, Union
 
     from appium.webdriver import Remote as AppiumWebDriver
     from PIL.Image import Image
@@ -64,7 +66,7 @@ class FrameResolver(object):
     def _ref_if_locator(self, frame_ref):
         if isinstance(frame_ref, FrameLocator):
             frame_locator = frame_ref
-            if frame_locator.frame_index:
+            if frame_locator.frame_index is not None:
                 frame_ref = frame_locator.frame_index
             if frame_locator.frame_name_or_id:
                 frame_ref = frame_locator.frame_name_or_id
@@ -133,8 +135,7 @@ class _EyesSwitchTo(object):
         :param frame_reference: The reference to the frame.
         """
         frame_res = FrameResolver(frame_reference, self._driver)
-        self.will_switch_to_frame(frame_res.eyes_webelement)
-        self._switch_to.frame(frame_res.webelement)
+        self._do_switch_to_frame(frame_res.eyes_webelement)
 
     def frames(self, frame_chain):
         # type: (FrameChain) -> None
@@ -181,12 +182,12 @@ class _EyesSwitchTo(object):
         del self._driver.frame_chain[:]
         self._switch_to.window(window_name)
 
-    def will_switch_to_frame(self, target_frame):
+    def _do_switch_to_frame(self, target_frame):
         # type: (EyesWebElement) -> None
         """
-        Will be called before switching into a frame.
+        Will be called when switching into a frame.
 
-        :param target_frame: The element about to be switched to.
+        :param target_frame: The element to be switched to.
         """
         argument_guard.not_none(target_frame)
 
@@ -198,14 +199,20 @@ class _EyesSwitchTo(object):
         content_location = Point(
             bounds["x"] + borders["left"], bounds["y"] + borders["top"]
         )
+        outer_size = RectangleSize.from_(target_frame.size)
+        inner_size = RectangleSize.from_(frame_inner_size)
         original_location = target_frame.scroll_location
 
+        self._switch_to.frame(target_frame.element)
+
+        scroll_root_element = self._driver.find_element_by_xpath("/*")
         frame = Frame(
             reference=target_frame,
             location=content_location,
-            outer_size=RectangleSize.from_(target_frame.size),
-            inner_size=RectangleSize.from_(frame_inner_size),
+            outer_size=outer_size,
+            inner_size=inner_size,
             parent_scroll_position=original_location,
+            scroll_root_element=scroll_root_element,
         )
         self._driver.frame_chain.push(frame)
 
@@ -272,7 +279,7 @@ class EyesWebDriver(object):
         """
         self._proxy_to_fields = all_attrs(driver)
         self._driver = driver  # type: Union[WebDriver, AppiumWebDriver]
-        self._eyes = eyes
+        self._eyes = eyes  # type: Eyes
         # List of frames the user switched to, and the current offset,
         # so we can properly calculate elements' coordinates
         self._frame_chain = FrameChain()
@@ -280,6 +287,7 @@ class EyesWebDriver(object):
 
         self.driver_takes_screenshot = driver.capabilities.get("takesScreenshot", False)
         self.rotation = None  # type: Optional[int]
+        self._user_agent = None  # type: Optional[UserAgent]
 
     @property
     def eyes(self):
@@ -289,12 +297,23 @@ class EyesWebDriver(object):
     @property
     def user_agent(self):
         # type: () -> useragent.UserAgent
+        if self.is_mobile_app:
+            major_version = minor_version = None
+            if self.platform_version:
+                major_version, minor_version = self.platform_version.split(".", 2)[:2]
+            self._user_agent = useragent.UserAgent(
+                os=self.platform_name,
+                os_major_version=major_version,
+                os_minor_version=minor_version,
+            )
+        if self._user_agent:
+            return self._user_agent
         try:
             ua_string = self._driver.execute_script("return navigator.userAgent")
-            user_agent = useragent.parse_user_agent_string(ua_string)
-        except WebDriverException:
-            user_agent = None
-        return user_agent
+            self._user_agent = useragent.parse_user_agent_string(ua_string)
+        except WebDriverException as e:
+            logger.exception(e)
+        return self._user_agent
 
     @property
     def session_id(self):
@@ -753,3 +772,17 @@ class EyesWebDriver(object):
             driver.quit()
         """
         self._driver.quit()
+
+    @contextlib.contextmanager
+    def saved_frame_chain(self):
+        # type: () -> ContextManager
+        """Context manager that saves and restores driver's frame chain"""
+        original_fc = self.frame_chain.clone()
+        try:
+            yield
+        finally:
+            if original_fc is not None:
+                self.switch_to.frames(original_fc)
+
+    def ensure_sync_with_underlying_driver(self):
+        webdriver_sync.ensure_sync_with_underlying_driver(self, self._driver)
